@@ -4,20 +4,20 @@
  * Copyright (C) 2001 Havoc Pennington
  * Copyright (C) 2002 Mathias Hasselmann
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * This file is part of gnome-terminal.
  *
- * This library is distributed in the hope that it will be useful,
+ * Gnome-terminal is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * Gnome-terminal is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "terminal-intl.h"
@@ -39,7 +39,6 @@
  * This sucks. ;-)
  */
 #define KEY_VISIBLE_NAME "visible_name"
-#define KEY_CURSOR_BLINK "cursor_blink"
 #define KEY_DEFAULT_SHOW_MENUBAR "default_show_menubar"
 #define KEY_FOREGROUND_COLOR "foreground_color"
 #define KEY_BACKGROUND_COLOR "background_color"
@@ -59,7 +58,6 @@
 #define KEY_CUSTOM_COMMAND "custom_command"
 #define KEY_ICON "icon"
 #define KEY_PALETTE "palette"
-#define KEY_X_FONT "x_font"
 #define KEY_BACKGROUND_TYPE "background_type"
 #define KEY_BACKGROUND_IMAGE "background_image"
 #define KEY_SCROLL_BACKGROUND "scroll_background"
@@ -103,8 +101,6 @@ struct _TerminalProfilePrivate
 
   GdkColor palette[TERMINAL_PALETTE_SIZE];
 
-  char *x_font;
-
   TerminalBackgroundType background_type;
   char *background_image_file;
   GdkPixbuf *background_image;
@@ -117,7 +113,6 @@ struct _TerminalProfilePrivate
   guint icon_load_failed : 1;
   guint background_load_failed : 1;
   
-  guint cursor_blink : 1;
   guint default_show_menubar : 1;
   guint allow_bold : 1;
   guint silent_bell : 1;
@@ -264,7 +259,6 @@ terminal_profile_init (TerminalProfile *profile)
   
   profile->priv = g_new0 (TerminalProfilePrivate, 1);
   terminal_setting_mask_clear (&profile->priv->locked);
-  profile->priv->cursor_blink = FALSE;
   profile->priv->default_show_menubar = TRUE;
   profile->priv->visible_name = g_strdup ("<not named>");
   profile->priv->foreground.red = 0;
@@ -285,7 +279,6 @@ terminal_profile_init (TerminalProfile *profile)
   memcpy (profile->priv->palette,
           terminal_palette_linux,
           TERMINAL_PALETTE_SIZE * sizeof (GdkColor));
-  profile->priv->x_font = g_strdup ("fixed");
   profile->priv->background_type = TERMINAL_BACKGROUND_SOLID;
   profile->priv->background_image_file = g_strdup ("");
   profile->priv->background_darkness = 0.0;
@@ -352,7 +345,6 @@ terminal_profile_finalize (GObject *object)
   g_free (profile->priv->icon_file);
   if (profile->priv->icon)
     g_object_unref (G_OBJECT (profile->priv->icon));
-  g_free (profile->priv->x_font);
 
   g_free (profile->priv->background_image_file);
   if (profile->priv->background_image)
@@ -490,33 +482,6 @@ terminal_profile_set_silent_bell (TerminalProfile  *profile,
   g_free (key);
 }
 
-gboolean
-terminal_profile_get_cursor_blink (TerminalProfile  *profile)
-{
-  g_return_val_if_fail (TERMINAL_IS_PROFILE (profile), FALSE);
-  
-  return profile->priv->cursor_blink;
-}
-
-void
-terminal_profile_set_cursor_blink (TerminalProfile *profile,
-                                   gboolean         setting)
-{
-  char *key;
-
-  RETURN_IF_NOTIFYING (profile);
-  
-  key = gconf_concat_dir_and_key (profile->priv->profile_dir,
-                                  KEY_CURSOR_BLINK);
-  
-  gconf_client_set_bool (profile->priv->conf,
-                         key,
-                         setting,
-                         NULL);
-
-  g_free (key);
-}
-
 gboolean
 terminal_profile_get_scroll_on_keystroke (TerminalProfile  *profile)
 {
@@ -1125,33 +1090,6 @@ terminal_profile_set_palette (TerminalProfile *profile,
   g_free (str);
 }
 
-const char*
-terminal_profile_get_x_font (TerminalProfile *profile)
-{
-  g_return_val_if_fail (TERMINAL_IS_PROFILE (profile), NULL);
-
-  return profile->priv->x_font;
-}
-
-void
-terminal_profile_set_x_font (TerminalProfile *profile,
-                             const char      *name)
-{
-  char *key;
-
-  RETURN_IF_NOTIFYING (profile);
-  
-  key = gconf_concat_dir_and_key (profile->priv->profile_dir,
-                                  KEY_X_FONT);
-  
-  gconf_client_set_string (profile->priv->conf,
-                           key,
-                           name,
-                           NULL);
-
-  g_free (key);
-}
-
 TerminalBackgroundType
 terminal_profile_get_background_type (TerminalProfile *profile)
 {
@@ -1774,25 +1712,6 @@ set_palette (TerminalProfile *profile,
   return FALSE;
 }
 
-static gboolean
-set_x_font (TerminalProfile *profile,
-            const char      *candidate_font)
-{
-  if (candidate_font &&
-      strcmp (profile->priv->x_font, candidate_font) == 0)
-    return FALSE;
-  
-  if (candidate_font != NULL)
-    {
-      g_free (profile->priv->x_font);
-      profile->priv->x_font = g_strdup (candidate_font);
-      return TRUE;
-    }
-  /* otherwise just leave the old font */
-  
-  return FALSE;
-}
-
 static gboolean
 set_background_type (TerminalProfile *profile,
                      const char      *str_val)
@@ -1923,6 +1842,8 @@ terminal_profile_update (TerminalProfile *profile)
   TerminalSettingMask locked;
   TerminalSettingMask old_locked;
   TerminalSettingMask mask;
+
+  g_return_if_fail (profile != NULL);
   
   terminal_setting_mask_clear (&mask);
   terminal_setting_mask_clear (&locked);
@@ -1985,7 +1906,6 @@ terminal_profile_update (TerminalProfile *profile)
     g_free (key);                                                               \
   }
 
-  UPDATE_BOOLEAN (KEY_CURSOR_BLINK,         cursor_blink);
   UPDATE_BOOLEAN (KEY_DEFAULT_SHOW_MENUBAR, default_show_menubar);
   UPDATE_STRING  (KEY_VISIBLE_NAME,         visible_name);
   UPDATE_STRING  (KEY_FOREGROUND_COLOR,     foreground_color);
@@ -2006,7 +1926,6 @@ terminal_profile_update (TerminalProfile *profile)
   UPDATE_STRING  (KEY_CUSTOM_COMMAND,       custom_command);
   UPDATE_STRING  (KEY_ICON,                 icon_file);
   UPDATE_STRING  (KEY_PALETTE,              palette);
-  UPDATE_STRING  (KEY_X_FONT,               x_font);
   UPDATE_STRING  (KEY_BACKGROUND_TYPE,      background_type);
   UPDATE_STRING  (KEY_BACKGROUND_IMAGE,     background_image_file);
   UPDATE_BOOLEAN (KEY_SCROLL_BACKGROUND,    scroll_background);
@@ -2132,7 +2051,6 @@ else if (strcmp (key, KName) == 0)                                      \
  if (0)
    {
      ;
-     UPDATE_BOOLEAN (KEY_CURSOR_BLINK,           cursor_blink,           FALSE);
      UPDATE_BOOLEAN (KEY_DEFAULT_SHOW_MENUBAR,   default_show_menubar,   FALSE);
      UPDATE_STRING  (KEY_VISIBLE_NAME,           visible_name,           NULL);
      UPDATE_STRING  (KEY_FOREGROUND_COLOR,       foreground_color,       NULL);
@@ -2153,7 +2071,6 @@ else if (strcmp (key, KName) == 0)                                      \
      UPDATE_STRING  (KEY_CUSTOM_COMMAND,         custom_command,         NULL);
      UPDATE_STRING  (KEY_ICON,                   icon_file,              NULL);
      UPDATE_STRING  (KEY_PALETTE,                palette,                NULL);
-     UPDATE_STRING  (KEY_X_FONT,                 x_font,                 NULL);
      UPDATE_STRING  (KEY_BACKGROUND_TYPE,        background_type,        NULL);
      UPDATE_STRING  (KEY_BACKGROUND_IMAGE,       background_image_file,  NULL);
      UPDATE_BOOLEAN (KEY_SCROLL_BACKGROUND,      scroll_background,      FALSE);
@@ -2334,11 +2251,18 @@ static int
 alphabetic_cmp (gconstpointer a,
                 gconstpointer b)
 {
+  int result;
+
   TerminalProfile *ap = (TerminalProfile*) a;
   TerminalProfile *bp = (TerminalProfile*) b;
 
-  return g_utf8_collate (terminal_profile_get_visible_name (ap),
-                         terminal_profile_get_visible_name (bp));
+  result =  g_utf8_collate (terminal_profile_get_visible_name (ap),
+			    terminal_profile_get_visible_name (bp));
+  if (!result)
+    result = strcmp (terminal_profile_get_name (ap),
+		     terminal_profile_get_name (bp));
+
+  return result;
 }
 
 GList*
@@ -2503,7 +2427,7 @@ emit_changed (TerminalProfile           *profile,
 }
 
 /* Function I'm cut-and-pasting everywhere, this is from msm */
-void
+static void
 dialog_add_details (GtkDialog  *dialog,
                     const char *details)
 {
@@ -2556,7 +2480,8 @@ dialog_add_details (GtkDialog  *dialog,
   gtk_widget_hide (label);
 }
 
-void
+/* returns actual name used for created profile */
+char *
 terminal_profile_create (TerminalProfile *base_profile,
                          const char      *visible_name,
                          GtkWindow       *transient_parent)
@@ -2614,16 +2539,6 @@ terminal_profile_create (TerminalProfile *base_profile,
                            &err);
   BAIL_OUT_CHECK ();
 
-  g_free (key);
-  key = gconf_concat_dir_and_key (profile_dir,
-                                  KEY_CURSOR_BLINK);
-
-  gconf_client_set_bool (base_profile->priv->conf,
-                         key,
-                         base_profile->priv->cursor_blink,
-                         &err);
-  BAIL_OUT_CHECK ();
-
   g_free (key);
   key = gconf_concat_dir_and_key (profile_dir,
                                   KEY_DEFAULT_SHOW_MENUBAR);
@@ -2821,14 +2736,6 @@ terminal_profile_create (TerminalProfile *base_profile,
   g_free (s);
   BAIL_OUT_CHECK ();
 
-  g_free (key);
-  key = gconf_concat_dir_and_key (profile_dir,
-                                  KEY_X_FONT);
-  gconf_client_set_string (base_profile->priv->conf,
-                           key, base_profile->priv->x_font,
-                           &err);
-  BAIL_OUT_CHECK ();
-
   g_free (key);
   key = gconf_concat_dir_and_key (profile_dir,
                                   KEY_BACKGROUND_TYPE);
@@ -2941,7 +2848,6 @@ terminal_profile_create (TerminalProfile *base_profile,
   BAIL_OUT_CHECK ();
   
  cleanup:
-  g_free (profile_name);
   g_free (profile_dir);
   g_free (key);
 
@@ -2978,10 +2884,14 @@ terminal_profile_create (TerminalProfile *base_profile,
         }
 
       g_error_free (err);
+
+      g_free (profile_name);
+      profile_name = NULL;
     }
-  
+
   g_object_unref (G_OBJECT (base_profile));
   g_object_unref (G_OBJECT (transient_parent));
+  return profile_name;
 }
 
 void
@@ -3107,7 +3017,7 @@ terminal_profile_get_for_new_term (TerminalProfile *current)
  * does not carry all the bytes, and xterm's palette is messed up...
  */
 
-gchar*
+static gchar*
 color_selection_palette_to_string (const GdkColor *colors, gint n_colors)
 {
   gint i;
@@ -3220,6 +3130,27 @@ terminal_setting_mask_equal (const TerminalSettingMask *a,
   return memcmp (a, b, sizeof (*a)) == 0;
 }
 
+const GdkColor
+terminal_palette_tango[TERMINAL_PALETTE_SIZE] =
+{
+  { 0, 0x2e2e, 0x3434, 0x3636 },
+  { 0, 0xcccc, 0x0000, 0x0000 },
+  { 0, 0x4e4e, 0x9a9a, 0x0606 },
+  { 0, 0xc4c4, 0xa0a0, 0x0000 },
+  { 0, 0x3434, 0x6565, 0xa4a4 },
+  { 0, 0x7575, 0x5050, 0x7b7b },
+  { 0, 0x0606, 0x9820, 0x9a9a },
+  { 0, 0xd3d3, 0xd7d7, 0xcfcf },
+  { 0, 0x5555, 0x5757, 0x5353 },
+  { 0, 0xefef, 0x2929, 0x2929 },
+  { 0, 0x8a8a, 0xe2e2, 0x3434 },
+  { 0, 0xfcfc, 0xe9e9, 0x4f4f },
+  { 0, 0x7272, 0x9f9f, 0xcfcf },
+  { 0, 0xadad, 0x7f7f, 0xa8a8 },
+  { 0, 0x3434, 0xe2e2, 0xe2e2 },
+  { 0, 0xeeee, 0xeeee, 0xecec }
+};
+
 const GdkColor
 terminal_palette_linux[TERMINAL_PALETTE_SIZE] =
 {
@@ -3283,27 +3214,6 @@ terminal_palette_rxvt[TERMINAL_PALETTE_SIZE] =
   { 0, 0xffff, 0xffff, 0xffff }
 };
 
-const GdkColor
-terminal_palette_tango[TERMINAL_PALETTE_SIZE] =
-{
-  { 0, 0x2e2e, 0x3434, 0x3636 },
-  { 0, 0xcccc, 0x0000, 0x0000 },
-  { 0, 0x4e4e, 0x9a9a, 0x0606 },
-  { 0, 0xc4c4, 0xa0a0, 0x0000 },
-  { 0, 0x3434, 0x6565, 0xa4a4 },
-  { 0, 0x7575, 0x5050, 0x7b7b },
-  { 0, 0x0606, 0x9820, 0x9a9a },
-  { 0, 0xd3d3, 0xd7d7, 0xcfcf },
-  { 0, 0x5555, 0x5757, 0x5353 },
-  { 0, 0xefef, 0x2929, 0x2929 },
-  { 0, 0x8a8a, 0xe2e2, 0x3434 },
-  { 0, 0xfcfc, 0xe9e9, 0x4f4f },
-  { 0, 0x7272, 0x9f9f, 0xcfcf },
-  { 0, 0xadad, 0x7f7f, 0xa8a8 },
-  { 0, 0x3434, 0xe2e2, 0xe2e2 },
-  { 0, 0xeeee, 0xeeee, 0xecec }
-};
-
 void
 profile_name_entry_notify (TerminalProfile *profile)
 {
